Quickstart — django-richtemplates v0.3.beta documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.beta documentation »

# Quickstart

django-richtemplates‘s source distribution comes with example project located at `example_project` of the archive. It’s settings module is configured so it would try to lookup django-richtemplates in it’s parent directory (so try not to move it).

Remember that django-richtemplates needs Django >=1.2 (see Installation and Configuration sections for more information).

Note

We strongly recommend to use virtualenv, virtualenvwrapper and pip combo. You could simply create virtual environment:

    mkvirtualenv --no-site-packages richtemplates_test

Simply follow those steps in order to get `example_project` running:

1. Go to the `example_project` directory
2. Install project’s requirements: `pip install -r requirements.txt`
3. Create sqlite database: `python manage.py syncdb`
4. Import `richtemplates` and `django-admin-tools` media folders: `python manage.py import_media richtemplates admin_tools`
5. Run development server `python manage.py runserver`
6. Visit `http://127.0.0.1:8000`

Example projects shows:

- Default django-richtemplates theme
- How messages are shown
- How to use `base.html`, `base_1col.html`, `layout/menu_top.html` and many more templates
- How to use django-pagination, django-filter and django-sorting with django-richtemplates.
- An example of how to use LimitingModelForm
- An example of how to use HTTP 403 Middleware

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.beta documentation »